String constants used as keys in the structured log additionalData map.
Using constants instead of inline strings prevents typos and enables rename-safe refactoring across the package.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- affected → const String
- args → const String
- cacheHit → const String
- durationMs → const String
- error → const String
- items → const String
- key → const String
- meta → const String
- namedArgs → const String
- operation → const String
- sizeBytes → const String
- slow → const String
- source → const String
- statement → const String
- statementDigest → const String
- success → const String
- table → const String
- target → const String
- transactionId → const String
- value → const String